@@ -8,7 +8,11 @@ module Celluloid
       def_delegators :@server, :listen, :sysaccept, :close, :closed?, :addr, :setsockopt
 
       def initialize(hostname_or_port, port = nil)
-        @server = ::TCPServer.new(hostname_or_port, port)
+        if port.nil?
+          @server = ::TCPServer.new(hostname_or_port)
+        else
+          @server = ::TCPServer.new(hostname_or_port, port)
+        end
       end
 
       def accept
